# == Define: ps1template::exec
#
# Execute a Powershell Command Template.
#
# === Parameters
#
# [*creates*]
#  The `creates` parameter for the exec resource that extracts the ZIP file,
#  default is undefined.
#
# [*refreshonly*]
#  The `refreshonly` parameter for the exec resource that extracts the ZIP file,
#  defaults to false.
#
# [*unless*]
#  The `unless` parameter for the exec resource that extracts the ZIP file,
#  default is undefined.
#
# [*command_template*]
#  Advanced paramter for generating PowerShell that extracts the ZIP file,
#  defaults to 'windows/unzip.ps1.erb'.
#
# [*timeout*]
#  Execution timeout in seconds for the unzip command; 0 disables timeout,
#  defaults to 300 seconds (5 minutes).
#
# [*cwd*]
#  Change to Working Directory.
#
# [*logoutput*]
#  Show Command Output. Default: false
#
# [*path*]
#  Specifiy the Coammnd Environment Path Variable. Default: $::path
#
define ps1template::exec(
  $creates          = undef,
  $refreshonly      = false,
  $unless           = undef,
  $command_template = 'exec/mvn clean install',
  $timeout          = 300,
  $cwd              = 'X:/AutomotiveServiceBus',
  $logoutput        = false,
  $path             = $::path,
  $tempfolder       = 'C:\puppet-module-ps1template-exec-temp',
) {
  validate_absolute_path($cwd)
  validate_absolute_path($tempfolder)

  if (! $creates and ! $refreshonly and ! $unless){
    fail("Must set one of creates, refreshonly, or unless parameters.\n")
  }

  $template_filename = basename($command_template)

  $exec_command_filename = "${tempfolder}\\${name}-${template_filename}.ps1"
  file { $exec_command_filename:
    content => template("ps1template/${command_template}.ps1.erb"),
    require => File[$tempfolder],
  }

  exec { "exec-template-file-${name}":
    command     => "powershell.exe -executionpolicy remotesigned -file \"${exec_command_filename}\"",
    creates     => $creates,
    refreshonly => $refreshonly,
    unless      => $unless,
    timeout     => $timeout,
    cwd         => $cwd,
    logoutput   => $logoutput,
    path        => $path,
    require     => File[$exec_command_filename],
  }

}
